#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL



#' sfdct.
#'
#' Triangulate simple features including the input edges as constraints, rather than
#' being bounded to the convex hull.
#'
#' @name sfdct-package
#' @docType package
NULL

#' Lake Superior polygons.
#'
#' See data-raw for original source.
#' @name lakesuperior
NULL

#' Antarctica, and not Antarctica.
#'
#' See data-raw for original source.
#' @name antarctica
#' @examples
#' library(sf)
#' plot(antarctica, col = rainbow(nrow(antarctica), alpha = 0.4))
NULL

#' The 'world' database from the `maps` package.
#'
#' Data is in `sf` form.
#' See data-raw for original source.
#' @name  map_world
NULL
